Documentation
¶
Index ¶
Constants ¶
const TransformerType = abstract.TransformerType("dbt")
Variables ¶
var NotSupportedErr = xerrors.New("DBT not supported")
Functions ¶
func GlobalDataDirectory ¶
func GlobalDataDirectory() string
func PluggableTransformer ¶
func PluggableTransformer(transfer *model.Transfer, _ metrics.Registry, cp coordinator.Coordinator) func(abstract.Sinker) abstract.Sinker
func Register ¶
func Register(f RegisterFunc)
Types ¶
type RegisterFunc ¶
type RegisterFunc = func(destination model.Destination) (SupportedDestination, error)
type SupportedDestination ¶
type SupportedDestination interface {
// DBTConfiguration provides a YAML-marshallable configuration of the target to be used by DBT.
//
// The object returned by this function must be the database-specific settings, namely the object inside `outputs`.
// Other DBT parameters will be set automatically by the common code.
DBTConfiguration(ctx context.Context) (any, error)
}
func ToSupportedDestination ¶
func ToSupportedDestination(destination model.Destination) (SupportedDestination, error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.